@@ -34,6 +34,7 @@ SEXP SP_PREFIX(Polygon_c)(SEXP coords, SEXP n, SEXP ihole) {
 
     PROTECT(ringDir = NEW_INTEGER(1)); pc++;
     INTEGER_POINTER(ringDir)[0] = (area > 0.0) ? -1 : 1;
+// -1 cw hole, 1 ccw not-hole
 
 /* RSB 100126 fixing hole assumption
  thanks to Javier Munoz for report */
@@ -474,6 +475,8 @@ SEXP SP_PREFIX(comment2comm)(SEXP obj) {
     }
 
     nc = length(STRING_ELT(comment, 0));
+    if (nc < 1) error("comment2comm: empty string comment");
+
     buf = (char *) R_alloc((size_t) (nc+1), sizeof(char));
 
     strcpy(buf, CHAR(STRING_ELT(comment, 0)));
